@@ -1,12 +1,16 @@
 from Form import *
-from Module import *
+from ModuleHandler import *
 
-class ModuleAdmin (Module, FormHelper):
+HELPS = [
+    ('modules_handlers_admin', "Remote Administration")
+]
+
+class ModuleAdmin (ModuleHandler):
     PROPERTIES = []
 
     def __init__ (self, cfg, prefix, submit):
-        Module.__init__ (self, 'admin', cfg, prefix, submit)
-        FormHelper.__init__ (self, 'admin', cfg)
+        ModuleHandler.__init__ (self, 'admin', cfg, prefix, submit)
+        self.show_document_root = False
 
     def _op_render (self):
         return ''
