@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2008 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2009 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -18,9 +18,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
- */
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
+ */ 
 
 #ifndef CHEROKEE_DIRLIST_HANDLER_H
 #define CHEROKEE_DIRLIST_HANDLER_H
@@ -102,7 +102,6 @@ typedef struct {
  	cherokee_buffer_t        header;
 
 	cherokee_buffer_t        public_dir;
-	cherokee_buffer_t       *software_str_ref;
 } cherokee_handler_dirlist_t;
 
 #define PROP_DIRLIST(x)      ((cherokee_handler_dirlist_props_t *)(x))
