@@ -278,6 +278,9 @@ cherokee_server_free (cherokee_server_t *srv)
 	if (srv->iocache)
 		cherokee_iocache_free (srv->iocache);
 
+	if (srv->cryptor)
+		cherokee_cryptor_free (srv->cryptor);
+
 	cherokee_nonce_table_free (srv->nonces);
 
 	/* Virtual servers
@@ -749,8 +752,8 @@ cherokee_server_initialize (cherokee_server_t *srv)
 {   
 	int                 re;
 	ret_t               ret;
-	struct passwd      *ent;
-	cherokee_list_t    *i;
+	cherokee_list_t    *i, *tmp;
+	struct passwd      *ent          = NULL;
 	cherokee_boolean_t  loggers_done = false;
 
 	/* Build the server string
@@ -787,6 +790,49 @@ cherokee_server_initialize (cherokee_server_t *srv)
 		return ret_error;
 	}
 
+	/* Init the SSL/TLS support
+	*/
+	ret = vservers_check_tls(srv);
+	switch (ret) {
+		case ret_ok:
+			srv->tls_enabled = true;
+			break;
+		case ret_not_found:
+			srv->tls_enabled = false;
+			break;		
+		case ret_error:
+			return ret_error;
+		default:
+			RET_UNKNOWN(ret);
+			return ret_error;
+	}
+
+	if (srv->tls_enabled) {
+		/* Init TLS
+		 */
+		ret = init_vservers_tls (srv);
+		if (ret != ret_ok) 
+			return ret;
+	} else {
+		/* Ensure no TLS ports are bound
+		 */
+		list_for_each_safe (i, tmp, &srv->listeners) {
+			if (! BIND_IS_TLS(i))
+				continue;
+			
+			PRINT_MSG ("WARNING: Ignoring TLS port %d\n", BIND(i)->port);
+			cherokee_list_del (i);
+			cherokee_bind_free (BIND(i));
+		}
+	}
+
+	/* Ensure there is at least one listener
+	*/
+	if (cherokee_list_empty (&srv->listeners)) {
+		PRINT_MSG_S("ERROR: No listening on any port\n");
+		return ret_error;
+	}
+
 	/* Initialize the incoming sockets
 	 */
 	list_for_each (i, &srv->listeners) {
@@ -798,29 +844,6 @@ cherokee_server_initialize (cherokee_server_t *srv)
 			return ret;
 	}
 
-	/* Init the SSL/TLS support
-	 */
-	ret = vservers_check_tls(srv);
-	switch (ret) {
-	case ret_ok:
-		srv->tls_enabled = true;
-		break;
-	case ret_not_found:
-		srv->tls_enabled = false;
-		break;		
-	case ret_error:
-		return ret_error;
-	default:
-		RET_UNKNOWN(ret);
-		return ret_error;
-	}
-
-	if (srv->tls_enabled) {
-		ret = init_vservers_tls (srv);
-		if (ret != ret_ok) 
-			return ret;
-	}
-
 	/* Verify the thread number and force it within sane limits.
 	 * See also subsequent fdlimit_per_threads.
 	 */
@@ -1454,12 +1477,14 @@ configure_server (cherokee_server_t *srv)
 
 	cherokee_list_sort (&srv->vservers, vserver_cmp);
 
-	/* Sanity checks
+	/* Sanity check: virtual servers
 	 */
 	ret = vservers_check_sanity (srv);
 	if (ret != ret_ok)
 		return ret;
 
+	/* Sanity check: Port Binds
+	 */
 	if (cherokee_list_empty (&srv->listeners)) {
 		cherokee_bind_t *listener;
 
