@@ -73,12 +73,13 @@ cherokee_virtual_server_new (cherokee_virtual_server_t **vserver, void *server)
 	CHEROKEE_MUTEX_INIT(&n->data.rx_mutex, NULL);
 	CHEROKEE_MUTEX_INIT(&n->data.tx_mutex, NULL);
 
-	/* TLS related files
+	/* TLS related
 	 */
+	n->verify_depth    = 1;
 	cherokee_buffer_init (&n->server_cert);
 	cherokee_buffer_init (&n->server_key);
 	cherokee_buffer_init (&n->certs_ca);
-	cherokee_buffer_init (&n->certs_client);
+	cherokee_buffer_init (&n->req_client_certs);
 
 	ret = cherokee_buffer_init (&n->root);
 	if (unlikely(ret < ret_ok))
@@ -107,7 +108,7 @@ cherokee_virtual_server_free (cherokee_virtual_server_t *vserver)
 	cherokee_buffer_mrproper (&vserver->server_cert);
 	cherokee_buffer_mrproper (&vserver->server_key);
 	cherokee_buffer_mrproper (&vserver->certs_ca);
-	cherokee_buffer_mrproper (&vserver->certs_client);
+	cherokee_buffer_mrproper (&vserver->req_client_certs);
 
 	if (vserver->error_handler != NULL) {
 		cherokee_config_entry_free (vserver->error_handler);
@@ -178,10 +179,10 @@ cherokee_virtual_server_init_tls (cherokee_virtual_server_t *vsrv)
 	    cherokee_buffer_is_empty (&vsrv->server_key))
 		return ret_not_found;
 
-	/* Check one or more are empty
+	/* Check if key or certificate are empty
 	 */
-	if (cherokee_buffer_is_empty (&vsrv->server_key) ||
-	    cherokee_buffer_is_empty (&vsrv->server_cert))
+	if (cherokee_buffer_is_empty (&vsrv->server_cert) ||
+	    cherokee_buffer_is_empty (&vsrv->server_key))
 		return ret_error;
 	
 	/* Instance virtual server's cryptor
@@ -370,6 +371,9 @@ init_entry_property (cherokee_config_node_t *conf, void *data)
 			entry->expiration_time = cherokee_eval_formated_time (tmp);
 		}
 
+	} else if (equal_buf_str (&conf->key, "rate")) {
+		entry->limit_bps = atoi(conf->val.buf);
+		
 	} else if (equal_buf_str (&conf->key, "match")) {
 		/* Ignore: Previously handled 
 		 */
@@ -692,6 +696,9 @@ configure_virtual_server_property (cherokee_config_node_t *conf, void *data)
 	} else if (equal_buf_str (&conf->key, "directory_index")) {
 		cherokee_config_node_read_list (conf, NULL, add_directory_index, vserver);
 
+	} else if (equal_buf_str (&conf->key, "ssl_verify_depth")) {
+		vserver->verify_depth = !!atoi (conf->val.buf);
+
 	} else if (equal_buf_str (&conf->key, "ssl_certificate_file")) {
 		cherokee_buffer_init (&vserver->server_cert);
 		cherokee_buffer_add_buffer (&vserver->server_cert, &conf->val);
@@ -704,9 +711,9 @@ configure_virtual_server_property (cherokee_config_node_t *conf, void *data)
 		cherokee_buffer_init (&vserver->certs_ca);
 		cherokee_buffer_add_buffer (&vserver->certs_ca, &conf->val);
 
-	} else if (equal_buf_str (&conf->key, "ssl_client_list_file")) {
-		cherokee_buffer_init (&vserver->certs_client);
-		cherokee_buffer_add_buffer (&vserver->certs_client, &conf->val);
+	} else if (equal_buf_str (&conf->key, "ssl_client_certs")) {
+		cherokee_buffer_init (&vserver->req_client_certs);
+		cherokee_buffer_add_buffer (&vserver->req_client_certs, &conf->val);
 
 	} else {
 		PRINT_MSG ("ERROR: Virtual Server: Unknown key '%s'\n", conf->key.buf);
