@@ -13,7 +13,7 @@ vserver!1!rule!850!auth!users = foo,alo
 
 class Test (TestBase):
     def __init__ (self):
-        TestBase.__init__ (self)
+        TestBase.__init__ (self, __file__)
         self.name             = "Auth basic, with users"
         self.request          = "GET /auth1users/ HTTP/1.0\r\n"
         self.expected_error   = 401
